@@ -1,4 +1,5 @@
-import lldb
+from typing import Callable
+
 from lldb import *
 from renderers.jb_lldb_format_specs import *
 from renderers.jb_lldb_utils import *
@@ -65,61 +66,45 @@ class PointerChildrenProvider(AbstractChildrenProvider):
         return self.pointee
 
 
-class NumberVisDescriptor(AbstractVisDescriptor):
-    numeric_types = {"bool", "short", "unsigned short", "int", "unsigned int", "unsigned", "long", "unsigned long",
-                     "long long", "unsigned long long", "__int128", "unsigned __int128", "half", "float", "double",
-                     "long double"}
-    integer_types = {"short": (2, True), "unsigned short": (2, False),
-                     "int": (4, True), "unsigned int": (4, False), "unsigned": (4, False),
-                     "long": (4, True), "unsigned long": (4, False),
-                     "long long": (8, True), "unsigned long long": (8, False),
-                     "__int128": (16, True), "unsigned __int128": (16, False),
-                     }
-    float_types = {"half", "float", "double", "long double"}
-    formats = {eFormatHex, eFormatHexNoPrefix, eFormatHexUppercase, eFormatHexUppercaseNoPrefix,
-               eFormatOctal, eFormatBinary, eFormatBinaryNoPrefix, eFormatDecimal, eFormatChar}
+class AbstractNumberVisDescriptor(AbstractVisDescriptor):
+    formats = {
+        eFormatHex, eFormatHexNoPrefix, eFormatHexUppercase, eFormatHexUppercaseNoPrefix,
+        eFormatOctal, eFormatBinary, eFormatBinaryNoPrefix, eFormatDecimal, eFormatChar
+    }
     eFormatHexShowBoth = eFormatBasicSpecsMask + 1
 
-    def __init__(self, char_type_name: str):
-        self.value_type_name = char_type_name
-        self.presenters = {}
-        self.default_presenter = lambda x, s: NumberVisDescriptor.output_integer(x, s)
+    def __init__(self):
+        self.presenters: dict[int, Callable[[lldb.SBValue, Stream], None]] = {}
+        self.default_presenter: Callable[[lldb.SBValue, Stream], None] = lambda x, s: NumberVisDescriptor.output_integer(x, s)
 
-        if self.value_type_name == "bool":
-            self.default_presenter = lambda x, s: s.output_keyword("true" if x.GetValueAsUnsigned() != 0 else "false")
+    @classmethod
+    def make_presenters(cls, size: int, signed: bool) -> dict[int, Callable[[lldb.SBValue, Stream], None]]:
+        format_hex = "0x{{:0{}x}}".format(size * 2)
+        format_no_prefix = "{{:0{}x}}".format(size * 2)
+        format_hex_uppercase = "0x{{:0{}X}}".format(size * 2)
+        format_hex_uppercase_no_prefix = "{{:0{}X}}".format(size * 2)
+        format_octal = "{{:0{}o}}".format(size * 3)
+        format_binary = "0b{{:0{}b}}".format(size * 8)
+        format_binary_no_prefix = "{{:0{}b}}".format(size * 8)
 
-        elif self.value_type_name in self.integer_types:
-            size, signed = self.integer_types[self.value_type_name]
-            format_hex = "0x{{:0{}x}}".format(size * 2)
-            format_no_prefix = "{{:0{}x}}".format(size * 2)
-            format_hex_uppercase = "0x{{:0{}X}}".format(size * 2)
-            format_hex_uppercase_no_prefix = "{{:0{}X}}".format(size * 2)
-            format_octal = "{{:0{}o}}".format(size * 3)
-            format_binary = "0b{{:0{}b}}".format(size * 8)
-            format_binary_no_prefix = "{{:0{}b}}".format(size * 8)
+        def output_number_with_hex(x, s: Stream):
+            NumberVisDescriptor.output_integer(x, s)
+            s.output(" [")
+            s.output_number(format_hex.format(x.GetValueAsUnsigned()))
+            s.output("]")
 
-            def output_number_with_hex(x, s: Stream):
-                NumberVisDescriptor.output_integer(x, s)
-                s.output(" [")
-                s.output_number(format_hex.format(x.GetValueAsUnsigned()))
-                s.output("]")
-
-            self.presenters = {
-                eFormatHex: lambda x, s: s.output_number(format_hex.format(x.GetValueAsUnsigned())),
-                eFormatHexNoPrefix: lambda x, s: s.output_number(format_no_prefix.format(x.GetValueAsUnsigned())),
-                eFormatHexUppercase: lambda x, s: s.output_number(format_hex_uppercase.format(x.GetValueAsUnsigned())),
-                eFormatHexUppercaseNoPrefix: lambda x, s: s.output_number(
-                    format_hex_uppercase_no_prefix.format(x.GetValueAsUnsigned())),
-                eFormatOctal: lambda x, s: s.output_number(format_octal.format(x.GetValueAsUnsigned())),
-                eFormatBinary: lambda x, s: s.output_number(format_binary.format(x.GetValueAsUnsigned())),
-                eFormatBinaryNoPrefix: lambda x, s: s.output_number(
-                    format_binary_no_prefix.format(x.GetValueAsUnsigned())),
-                eFormatDecimal: lambda x, s: NumberVisDescriptor.output_decimal(x, signed, s),
-                eFormatChar: lambda x, s: NumberVisDescriptor.output_char(x.GetValueAsUnsigned(), s),
-                self.eFormatHexShowBoth: output_number_with_hex,
-            }
-        elif self.value_type_name in self.float_types:
-            self.default_presenter = lambda x, s: NumberVisDescriptor.output_float(x, s)
+        return {
+            eFormatHex: lambda x, s: s.output_number(format_hex.format(x.GetValueAsUnsigned())),
+            eFormatHexNoPrefix: lambda x, s: s.output_number(format_no_prefix.format(x.GetValueAsUnsigned())),
+            eFormatHexUppercase: lambda x, s: s.output_number(format_hex_uppercase.format(x.GetValueAsUnsigned())),
+            eFormatHexUppercaseNoPrefix: lambda x, s: s.output_number(format_hex_uppercase_no_prefix.format(x.GetValueAsUnsigned())),
+            eFormatOctal: lambda x, s: s.output_number(format_octal.format(x.GetValueAsUnsigned())),
+            eFormatBinary: lambda x, s: s.output_number(format_binary.format(x.GetValueAsUnsigned())),
+            eFormatBinaryNoPrefix: lambda x, s: s.output_number(format_binary_no_prefix.format(x.GetValueAsUnsigned())),
+            eFormatDecimal: lambda x, s: NumberVisDescriptor.output_decimal(x, signed, s),
+            eFormatChar: lambda x, s: NumberVisDescriptor.output_char(x.GetValueAsUnsigned(), s),
+            cls.eFormatHexShowBoth: output_number_with_hex
+        }
 
     @staticmethod
     def output_char(code: int, stream: Stream):
@@ -168,13 +153,46 @@ class NumberVisDescriptor(AbstractVisDescriptor):
         presenter(value_non_synth, stream)
 
 
+class NumberVisDescriptor(AbstractNumberVisDescriptor):
+    integer_types = {
+        "char": (1, True), "signed char": (1, True), "unsigned char": (1, False),
+        "short": (2, True), "unsigned short": (2, False),
+        "int": (4, True), "unsigned int": (4, False), "unsigned": (4, False),
+        "long": (4, True), "unsigned long": (4, False),
+        "long long": (8, True), "unsigned long long": (8, False),
+        "__int128": (16, True), "unsigned __int128": (16, False),
+        "char8_t": (1, False), "wchar_t": (2, False), "char16_t": (2, False), "char32_t": (4, False)
+    }
+    float_types = {"half", "float", "double", "long double"}
+
+    @classmethod
+    def is_number_type(cls, type_name: str) -> bool:
+        return type_name == "bool" or type_name in cls.integer_types or type_name in cls.float_types
+
+    def __init__(self, value_type_name: str):
+        super().__init__()
+        if value_type_name == "bool":
+            self.default_presenter = lambda x, s: s.output_keyword("true" if x.GetValueAsUnsigned() != 0 else "false")
+        elif value_type_name in self.integer_types:
+            size, signed = self.integer_types[value_type_name]
+            self.presenters = self.make_presenters(size, signed)
+        elif value_type_name in self.float_types:
+            self.default_presenter = lambda x, s: NumberVisDescriptor.output_float(x, s)
+
+
+class PointerAsIntegerVisDescriptor(AbstractNumberVisDescriptor):
+    def __init__(self, pointer_size: int):
+        super().__init__()
+        self.presenters = self.make_presenters(pointer_size, False)
+
+
 class CharVisDescriptor(AbstractVisDescriptor):
     char_types = {
         "char": CharPresentationInfo(1, lldb.eBasicTypeChar),
         "unsigned char": CharPresentationInfo(1, lldb.eBasicTypeUnsignedChar),
         "signed char": CharPresentationInfo(1, lldb.eBasicTypeSignedChar),
         "wchar_t": CharPresentationInfo(2, lldb.eBasicTypeWChar, 'utf-16', "L"),
-        "char8_t": CharPresentationInfo(1, lldb.eBasicTypeUnsignedChar, 'utf-8'),
+        "char8_t": CharPresentationInfo(1, lldb.eBasicTypeChar8, 'utf-8', "u8"),
         "char16_t": CharPresentationInfo(2, lldb.eBasicTypeChar16, 'utf-16', "u"),
         "char32_t": CharPresentationInfo(4, lldb.eBasicTypeChar32, 'utf-32', "U")
     }
