@@ -18,7 +18,7 @@ from renderers.jb_lldb_declarative_formatters_options import *
 from renderers.jb_lldb_evaluation_utils import resolve_type_wildcards
 from renderers.jb_lldb_format import overlay_child_format, update_value_dynamic_state, overlay_summary_format
 from renderers.jb_lldb_format_specs import *
-from renderers.jb_lldb_logging import get_suppress_errors
+from renderers.jb_lldb_logging_manager import RENDER_LOG
 from renderers.jb_lldb_natvis_synthetic_item_type_viz_cache import NatvisSyntheticItemTypeVizCache
 from renderers.jb_lldb_utils import *
 
@@ -33,7 +33,7 @@ class AbstractNatVisWithChildrenDescriptor(AbstractVisDescriptor):
                 type_wildcards=type_wildcards)
 
             if not viz.summaries:
-                log('No user provided summary found, return default...')
+                RENDER_LOG.info('No user provided summary found, return default...')
                 self._output_summary_from_children(value_non_synth, stream)
                 return True
 
@@ -92,7 +92,7 @@ class AbstractNatVisWithChildrenDescriptor(AbstractVisDescriptor):
             start_indexes = _calculate_child_providers_start_indexes(providers)
             return NatVisChildrenProvider(value_non_synth, viz, providers, start_indexes, type_wildcards)
         except EvaluateError as error:
-            log("Error occurred: {}", error)
+            RENDER_LOG.error("Error occurred: %s", error)
             return None
         finally:
             set_recursion_level(recursion_level)
@@ -106,26 +106,26 @@ class NatVisDescriptor(AbstractNatVisWithChildrenDescriptor):
 
     def output_summary(self, value_non_synth: lldb.SBValue, stream: Stream):
         for viz, type_viz_name, type_wildcards in self.viz_candidates:
-            log("Trying visualizer for type '{}'...", type_viz_name)
+            RENDER_LOG.info("Trying visualizer for type '%s'...", type_viz_name)
             if not _check_include_exclude_view_condition(viz, value_non_synth):
                 continue
             if self._output_viz_summary(value_non_synth, viz, type_wildcards, stream):
                 return
 
-        log("No matching display string candidate found, fallback to default")
-        return self._output_summary_from_children(value_non_synth, stream)
+        RENDER_LOG.info("No matching display string candidate found, fallback to default")
+        self._output_summary_from_children(value_non_synth, stream)
 
 
     def prepare_children(self, value_non_synth: lldb.SBValue):
         value_name = value_non_synth.GetName()
         value_type_name = value_non_synth.GetTypeName()
-        log("Initial retrieving children of value named '{}' of type '{}'...", value_name, value_type_name)
+        RENDER_LOG.info("Initial retrieving children of value named '%s' of type '%s'...", value_name, value_type_name)
 
         level = get_recursion_level()
         if level >= g_max_recursion_level - 1:
-            log("Natvis visualizer for type '{}' of value '{}' has been ignored: "
-                "recursion level exceeds the maximum supported limit of {}",
-                value_type_name, value_name, g_max_recursion_level)
+            RENDER_LOG.warning("Natvis visualizer for type '%s' of value '%s' has been ignored: "
+                               "recursion level exceeds the maximum supported limit of %s",
+                               value_type_name, value_name, g_max_recursion_level)
             return StructChildrenProvider(value_non_synth)
 
         for viz, type_viz_name, type_wildcards in self.viz_candidates:
@@ -134,12 +134,12 @@ class NatVisDescriptor(AbstractNatVisWithChildrenDescriptor):
             if viz.item_providers is None:
                 continue
 
-            log("Trying visualizer for type '{}'...", type_viz_name)
+            RENDER_LOG.info("Trying visualizer for type '%s'...", type_viz_name)
             provider = self._try_make_children_provider(value_non_synth, level, viz, type_wildcards)
             if provider is not None:
                 return provider
 
-        log("No child provider found for '{}'", value_type_name)
+        RENDER_LOG.info("No child provider found for '%s'", value_type_name)
         return StructChildrenProvider(value_non_synth)
 
 
@@ -149,29 +149,29 @@ class NatVisSyntheticItemDescriptor(AbstractNatVisWithChildrenDescriptor):
         self.type_wildcards = type_wildcards
 
     def output_summary(self, value_non_synth: lldb.SBValue, stream: Stream):
-        log("Trying visualizer for synthetic item '{}'...", self.viz.name)
+        RENDER_LOG.info("Trying visualizer for synthetic item '%s'...", self.viz.name)
 
         self_reference = NatvisSyntheticItemTypeVizCache.get_self_reference_in_synthetic_item(value_non_synth)
         if self._output_viz_summary(self_reference, self.viz, self.type_wildcards, stream):
             return
 
-        log("No matching display string candidate found, fallback to default")
+        RENDER_LOG.info("No matching display string candidate found, fallback to default")
         self._output_summary_from_children(self_reference, stream)
 
     def prepare_children(self, value_non_synth: lldb.SBValue) -> AbstractChildrenProvider:
-        log("Initial retrieving children of synthetic item '{}'...", self.viz.name)
+        RENDER_LOG.info("Initial retrieving children of synthetic item '%s'...", self.viz.name)
         level = get_recursion_level()
         if level >= g_max_recursion_level - 1:
-            log("Natvis visualizer for synthetic item '{}' has been ignored: "
-                "recursion level exceeds the maximum supported limit of {}",
-                self.viz.name, g_max_recursion_level)
+            RENDER_LOG.warning("Natvis visualizer for synthetic item '%s' has been ignored: "
+                               "recursion level exceeds the maximum supported limit of %s",
+                               self.viz.name, g_max_recursion_level)
             return g_empty_children_provider
 
         if not self.viz.item_providers:
-            log("No child provider found for '{}'", self.viz.name)
+            RENDER_LOG.info("No child provider found for '%s'", self.viz.name)
             return g_empty_children_provider
 
-        log("Trying visualizer for synthetic item '{}'...", self.viz.name)
+        RENDER_LOG.info("Trying visualizer for synthetic item '%s'...", self.viz.name)
         self_reference = NatvisSyntheticItemTypeVizCache.get_self_reference_in_synthetic_item(value_non_synth)
         provider = self._try_make_children_provider(self_reference, level, self.viz, self.type_wildcards)
         return provider if provider is not None else g_empty_children_provider
@@ -203,8 +203,7 @@ class NatVisChildrenProvider(AbstractChildrenProvider):
                 index = prov.get_child_index(name)
             except Exception:
                 # some unexpected error happened
-                if not get_suppress_errors():
-                    raise
+                RENDER_LOG.exception("Cannot get child index")
                 return INVALID_CHILD_INDEX
 
             if index != INVALID_CHILD_INDEX:
@@ -233,8 +232,7 @@ class NatVisChildrenProvider(AbstractChildrenProvider):
             return child
         except Exception:
             # some unexpected error happened
-            if not get_suppress_errors():
-                raise
+            RENDER_LOG.exception("Cannot get child at index")
             return None
         finally:
             IntrinsicsPrologCache.rollback_current_intrinsics_scope()
@@ -326,11 +324,11 @@ def _evaluate_interpolated_string(interp_string: TypeVizInterpolatedString, ctx_
 def _check_include_exclude_view_condition(viz: TypeViz, value_non_synth: lldb.SBValue) -> bool:
     if viz.include_view_id != 0:
         if get_custom_view_id(value_non_synth.GetFormat()) != viz.include_view_id:
-            log("IncludeView condition is not satisfied '{}'...", str(viz.include_view))
+            RENDER_LOG.info("IncludeView condition is not satisfied '%s'...", viz.include_view)
             return False
     if viz.exclude_view_id != 0:
         if get_custom_view_id(value_non_synth.GetFormat()) == viz.exclude_view_id:
-            log("ExcludeView condition is not satisfied '{}'...", str(viz.exclude_view))
+            RENDER_LOG.info("ExcludeView condition is not satisfied '%s'...", viz.exclude_view)
             return False
     return True
 
@@ -776,17 +774,17 @@ def _trying_eval_list_item_indexed_value(expression: str, ctx_val: lldb.SBValue,
         if not type_doesnt_have_subscript:
             raise
 
-    log("Subscript operator is missing. Wa are trying to get children via natvis. "
-        "At the moment, we only support the simple syntax 'member[$i]'")
+    RENDER_LOG.info("Subscript operator is missing. Wa are trying to get children via natvis. "
+                    "At the moment, we only support the simple syntax 'member[$i]'")
 
     res = LIST_ITEM_SUBSCRIPT_INDEX_REGEX.search(expression)
     if res is None:
-        log("We can't find expression '[$i]' for evaluate in '{}'", expression)
+        RENDER_LOG.error("We can't find expression '[$i]' for evaluate in '%s'", expression)
         raise EvaluateError("We can't find expression '[$i]' for evaluate")
 
     another_occurrence = LIST_ITEM_SUBSCRIPT_INDEX_REGEX.search(expression, pos=res.end())
     if another_occurrence is not None:
-        log("There are more than one expression '[$i]' in '{}'", expression)
+        RENDER_LOG.error("There are more than one expression '[$i]' in '%s'", expression)
         raise EvaluateError("More than one expression '[$i]'")
 
     child_item_expression = expression[:res.start()]
@@ -816,8 +814,8 @@ def _trying_get_indexed_item_value(expression: str, ctx_val: lldb.SBValue, idx:
         force_evaluate_children_count = value.num_children
 
         if child_item_type_name not in IndexListItemsProvider.types_with_index_list_items:
-            log("IndexListItems expression '{}' doesn't have subscript operator "
-                "and doesn't have implementation in natvis type '{}'", expression, child_item_type_name)
+            RENDER_LOG.error("IndexListItems expression '%s' doesn't have subscript operator "
+                             "and doesn't have implementation in natvis type '%s'", expression, child_item_type_name)
             raise EvaluateError("IndexListItems item doesn't have subscript operator")
 
         g_cache_subscript_is_missing[type_name][expression] = child_item_expression
